@@ -12,7 +12,8 @@ int cmd_key(context_t *context) {
   int i;
   int c;
   char *cmd = *context->argv;
-  xdo_active_mods_t *active_mods = NULL;
+  charcodemap_t *active_mods = NULL;
+  int active_mods_n;
   useconds_t delay = 12000;
   const char *window_arg = NULL;
   int free_arg = 0;
@@ -85,11 +86,11 @@ int cmd_key(context_t *context) {
   int (*keyfunc)(const xdo_t *, Window, const char *, useconds_t) = NULL;
 
   if (!strcmp(cmd, "key")) {
-    keyfunc = xdo_keysequence;
+    keyfunc = xdo_send_keysequence_window;
   } else if (!strcmp(cmd, "keyup")) {
-    keyfunc = xdo_keysequence_up;
+    keyfunc = xdo_send_keysequence_window_up;
   } else if (!strcmp(cmd, "keydown")) {
-    keyfunc = xdo_keysequence_down;
+    keyfunc = xdo_send_keysequence_window_down;
   } else {
     fprintf(stderr, "Unknown command '%s'\n", cmd);
     return 1;
@@ -98,8 +99,8 @@ int cmd_key(context_t *context) {
   int max_arg = context->argc;
   window_each(context, window_arg, {
     if (clear_modifiers) {
-      active_mods = xdo_get_active_modifiers(context->xdo);
-      xdo_clear_active_modifiers(context->xdo, window, active_mods);
+      xdo_get_active_modifiers(context->xdo, &active_mods, &active_mods_n);
+      xdo_clear_active_modifiers(context->xdo, window, active_mods, active_mods_n);
     }
 
     for (i = 0; i < context->argc; i++) {
@@ -110,15 +111,15 @@ int cmd_key(context_t *context) {
       int tmp = keyfunc(context->xdo, window, context->argv[i], delay);
       if (tmp != 0) {
         fprintf(stderr,
-                "xdo_keysequence reported an error for string '%s'\n",
+                "xdo_send_keysequence_window reported an error for string '%s'\n",
                 context->argv[i]);
       }
       ret += tmp;
     }
 
     if (clear_modifiers) {
-      xdo_set_active_modifiers(context->xdo, window, active_mods);
-      xdo_free_active_modifiers(active_mods);
+      xdo_set_active_modifiers(context->xdo, window, active_mods, active_mods_n);
+      free(active_mods);
     }
   }); /* window_each(...) */
 
