@@ -136,7 +136,8 @@ int cmd_mousemove(context_t *context) {
 
 static int _mousemove(context_t *context, struct mousemove *mousemove) {
   int ret;
-  xdo_active_mods_t *active_mods = NULL;
+  charcodemap_t *active_mods = NULL;
+  int active_mods_n;
 
   int x = mousemove->x;
   int y = mousemove->y;
@@ -146,7 +147,7 @@ static int _mousemove(context_t *context, struct mousemove *mousemove) {
   /* Save the mouse position if the window is CURRENTWINDOW */
   if (window == CURRENTWINDOW) {
     context->have_last_mouse = True;
-    xdo_mouselocation(context->xdo, &(context->last_mouse_x),
+    xdo_get_mouse_location(context->xdo, &(context->last_mouse_x),
                       &(context->last_mouse_y), &(context->last_mouse_screen));
   }
   
@@ -182,7 +183,7 @@ static int _mousemove(context_t *context, struct mousemove *mousemove) {
   }
 
   int mx, my, mscreen;
-  xdo_mouselocation(context->xdo, &mx, &my, &mscreen);
+  xdo_get_mouse_location(context->xdo, &mx, &my, &mscreen);
 
   /* Break early if we don't need to move */
   if (mx == x && my == y && mscreen == screen) {
@@ -190,15 +191,15 @@ static int _mousemove(context_t *context, struct mousemove *mousemove) {
   }
 
   if (mousemove->clear_modifiers) {
-    active_mods = xdo_get_active_modifiers(context->xdo);
-    xdo_clear_active_modifiers(context->xdo, window, active_mods);
+    xdo_get_active_modifiers(context->xdo, &active_mods, &active_mods_n);
+    xdo_clear_active_modifiers(context->xdo, window, active_mods, active_mods_n);
   }
 
   if (mousemove->step == 0) {
     if (window != CURRENTWINDOW && !mousemove->polar_coordinates) {
-      ret = xdo_mousemove_relative_to_window(context->xdo, window, x, y);
+      ret = xdo_move_mouse_relative_to_window(context->xdo, window, x, y);
     } else {
-      ret = xdo_mousemove(context->xdo, x, y, screen);
+      ret = xdo_move_mouse(context->xdo, x, y, screen);
     }
   } else {
     if (mx == x && my == y && mscreen == screen) {
@@ -209,24 +210,24 @@ static int _mousemove(context_t *context, struct mousemove *mousemove) {
     fprintf(stderr, "--step support not yet implemented\n");
 
     if (window > 0) {
-      ret = xdo_mousemove_relative_to_window(context->xdo, window, x, y);
+      ret = xdo_move_mouse_relative_to_window(context->xdo, window, x, y);
     } else {
-      ret = xdo_mousemove(context->xdo, x, y, screen);
+      ret = xdo_move_mouse(context->xdo, x, y, screen);
     }
   }
 
   if (ret) {
-    fprintf(stderr, "xdo_mousemove reported an error\n");
+    fprintf(stderr, "xdo_move_mouse reported an error\n");
   } else {
     if (mousemove->opsync) {
       /* Wait until the mouse moves away from its current position */
-      xdo_mouse_wait_for_move_from(context->xdo, mx, my);
+      xdo_wait_for_mouse_move_from(context->xdo, mx, my);
     }
   }
 
   if (mousemove->clear_modifiers) {
-    xdo_set_active_modifiers(context->xdo, window, active_mods);
-    xdo_free_active_modifiers(active_mods);
+    xdo_set_active_modifiers(context->xdo, window, active_mods, active_mods_n);
+    free(active_mods);
   }
 
   return 0;
