@@ -41,9 +41,9 @@ class XdotoolCommandKeyTests < Test::Unit::TestCase
 
   def test_chaining
     xdotool_ok "windowfocus --sync #{@wid}"
-    xdotool_ok "getwindowfocus key a b c d e"
-    xdotool_ok "getwindowfocus key --window %1 a b c d e"
-    xdotool_ok "getwindowfocus key --window %@ a b c d e"
+    xdotool_ok "getwindowfocus -f key a b c d e"
+    xdotool_ok "getwindowfocus -f key --window %1 a b c d e"
+    xdotool_ok "getwindowfocus -f key --window %@ a b c d e"
   end
 end # class XdotoolCommandKeyTests 
 
