@@ -12,6 +12,7 @@
 #include <X11/Xlib.h>
 #include <X11/X.h>
 #include <unistd.h>
+#include <wchar.h>
 
 /**
  * @mainpage
@@ -39,7 +40,7 @@
 
 /**
  * CURRENTWINDOW is a special identify for xdo input faking (mouse and
- * keyboard) functions like xdo_keysequence that indicate we should target the
+ * keyboard) functions like xdo_send_keysequence_window that indicate we should target the
  * current window, not a specific window.
  *
  * Generally, this means we will use XTEST instead of XSendEvent when sending
@@ -53,7 +54,7 @@
  */
 typedef struct keysym_charmap {
   const char *keysym;
-  char key;
+  wchar_t key;
 } keysym_charmap_t;
 
 /**
@@ -62,7 +63,7 @@ typedef struct keysym_charmap {
  * this key (keycode, modifiers, key index, etc)
  */
 typedef struct charcodemap {
-  char key; /** the letter for this key, like 'a' */
+  wchar_t key; /** the letter for this key, like 'a' */
   KeyCode code; /** the keycode that this key is on */
   KeySym symbol; /** the symbol representing this key */
   int index; /** the index in the keysym-per-keycode list that is this key */
@@ -72,6 +73,10 @@ typedef struct charcodemap {
   int needs_binding;
 } charcodemap_t;
 
+typedef enum {
+  XDO_FEATURE_XTEST, /** Is XTest available? */
+} XDO_FEATURES;
+
 /**
  * The main context.
  */
@@ -106,57 +111,53 @@ typedef struct xdo {
 
   /** Should we close the display when calling xdo_free? */
   int close_display_when_freed;
+
+  /** Be extra quiet? (omits some error/message output) */
+  int quiet;
+
+  /** Enable debug output? */
+  int debug;
+
+  /** Feature flags, such as XDO_FEATURE_XTEST, etc... */
+  int features_mask;
+
 } xdo_t;
 
 
-/**
- * Represents the list of active modifier keys at the time of an
- * xdo_get_active_modifiers call.
- *
- * @see xdo_get_active_modifiers
- * @see xdo_free_active_modifiers
- */
-typedef struct xdo_active_mods {
-  charcodemap_t *keymods;
-  int nkeymods;
-  unsigned int input_state;
-} xdo_active_mods_t;
-
-
 /**
  * Search only window title. DEPRECATED - Use SEARCH_NAME
- * @see xdo_window_search
+ * @see xdo_search_windows
  */
 #define SEARCH_TITLE (1UL << 0)
 
 /**
  * Search only window class.
- * @see xdo_window_search
+ * @see xdo_search_windows
  */
 #define SEARCH_CLASS (1UL << 1)
 
 /**
  * Search only window name.
- * @see xdo_window_search
+ * @see xdo_search_windows
  */
 #define SEARCH_NAME (1UL << 2)
 
 /**
  * Search only window pid.
- * @see xdo_window_search
+ * @see xdo_search_windows
  */
 #define SEARCH_PID  (1UL << 3)
 
 /**
  * Search only visible windows.
- * @see xdo_window_search
+ * @see xdo_search_windows
  */
 #define SEARCH_ONLYVISIBLE  (1UL << 4)
 
 /**
  * Search only a specific screen. 
  * @see xdo_search.screen
- * @see xdo_window_search
+ * @see xdo_search_windows
  */
 #define SEARCH_SCREEN  (1UL << 5)
 
@@ -166,11 +167,18 @@ typedef struct xdo_active_mods {
  */
 #define SEARCH_CLASSNAME (1UL << 6)
 
+/**
+ * Search a specific desktop
+ * @see xdo_search.screen
+ * @see xdo_search_windows
+ */
+#define SEARCH_DESKTOP (1UL << 7)
+
 
 /**
  * The window search query structure.
  *
- * @see xdo_window_search
+ * @see xdo_search_windows
  */
 typedef struct xdo_search {
   const char *title;        /** pattern to test against a window title */
@@ -191,6 +199,12 @@ typedef struct xdo_search {
    * @see SEARCH_NAME, SEARCH_CLASS, SEARCH_PID, SEARCH_CLASSNAME, etc
    */
   unsigned int searchmask; 
+
+  /** What desktop to search, if any. If none given, search all screens. */
+  long desktop;
+
+  /** How many results to return? If 0, return all. */
+  unsigned int limit;
 } xdo_search_t;
 
 #define XDO_ERROR 1
@@ -204,7 +218,7 @@ typedef struct xdo_search {
  *
  * @return Pointer to a new xdo_t or NULL on failure
  */
-xdo_t* xdo_new(char *display);
+xdo_t* xdo_new(const char *display);
 
 /**
  * Create a new xdo_t instance with an existing X11 Display instance.
@@ -236,7 +250,7 @@ void xdo_free(xdo_t *xdo);
  * @param y the target Y coordinate on the screen in pixels.
  * @param screen the screen (number) you want to move on.
  */
-int xdo_mousemove(const xdo_t *xdo, int x, int y, int screen);
+int xdo_move_mouse(const xdo_t *xdo, int x, int y, int screen);
 
 /**
  * Move the mouse to a specific location relative to the top-left corner
@@ -245,7 +259,7 @@ int xdo_mousemove(const xdo_t *xdo, int x, int y, int screen);
  * @param x the target X coordinate on the screen in pixels.
  * @param y the target Y coordinate on the screen in pixels.
  */
-int xdo_mousemove_relative_to_window(const xdo_t *xdo, Window window, int x, int y);
+int xdo_move_mouse_relative_to_window(const xdo_t *xdo, Window window, int x, int y);
 
 /**
  * Move the mouse relative to it's current position.
@@ -253,7 +267,7 @@ int xdo_mousemove_relative_to_window(const xdo_t *xdo, Window window, int x, int
  * @param x the distance in pixels to move on the X axis.
  * @param y the distance in pixels to move on the Y axis.
  */
-int xdo_mousemove_relative(const xdo_t *xdo, int x, int y);
+int xdo_move_mouse_relative(const xdo_t *xdo, int x, int y);
 
 /**
  * Send a mouse press (aka mouse down) for a given button at the current mouse
@@ -263,7 +277,7 @@ int xdo_mousemove_relative(const xdo_t *xdo, int x, int y);
  * @param button The mouse button. Generally, 1 is left, 2 is middle, 3 is
  *    right, 4 is wheel up, 5 is wheel down.
  */
-int xdo_mousedown(const xdo_t *xdo, Window window, int button);
+int xdo_mouse_down(const xdo_t *xdo, Window window, int button);
 
 /**
  * Send a mouse release (aka mouse up) for a given button at the current mouse
@@ -273,7 +287,7 @@ int xdo_mousedown(const xdo_t *xdo, Window window, int button);
  * @param button The mouse button. Generally, 1 is left, 2 is middle, 3 is
  *    right, 4 is wheel up, 5 is wheel down.
  */
-int xdo_mouseup(const xdo_t *xdo, Window window, int button);
+int xdo_mouse_up(const xdo_t *xdo, Window window, int button);
 
 /**
  * Get the current mouse location (coordinates and screen number).
@@ -282,14 +296,14 @@ int xdo_mouseup(const xdo_t *xdo, Window window, int button);
  * @param y integer pointer where the Y coordinate will be stored
  * @param screen_num integer pointer where the screen number will be stored
  */
-int xdo_mouselocation(const xdo_t *xdo, int *x, int *y, int *screen_num);
+int xdo_get_mouse_location(const xdo_t *xdo, int *x, int *y, int *screen_num);
 
 /**
  * Get the window the mouse is currently over
  *
  * @param window_ret Winter pointer where the window will be stored.
  */
-int xdo_mousewindow(const xdo_t *xdo, Window *window_ret);
+int xdo_get_window_at_mouse(const xdo_t *xdo, Window *window_ret);
 
 /**
  * Get all mouse location-related data.
@@ -303,8 +317,8 @@ int xdo_mousewindow(const xdo_t *xdo, Window *window_ret);
  * @param window Window pointer where the window/client the mouse is over
  *   will be stored.
  */
-int xdo_mouselocation2(const xdo_t *xdo, int *x_ret, int *y_ret,
-                       int *screen_num_ret, Window *window_ret);
+int xdo_get_mouse_location2(const xdo_t *xdo, int *x_ret, int *y_ret,
+                            int *screen_num_ret, Window *window_ret);
 
 /**
  * Wait for the mouse to move from a location. This function will block
@@ -313,7 +327,7 @@ int xdo_mouselocation2(const xdo_t *xdo, int *x_ret, int *y_ret,
  * @param origin_x the X position you expect the mouse to move from
  * @param origin_y the Y position you expect the mouse to move from
  */
-int xdo_mouse_wait_for_move_from(const xdo_t *xdo, int origin_x, int origin_y);
+int xdo_wait_for_mouse_move_from(const xdo_t *xdo, int origin_x, int origin_y);
 
 /**
  * Wait for the mouse to move to a location. This function will block
@@ -322,7 +336,7 @@ int xdo_mouse_wait_for_move_from(const xdo_t *xdo, int origin_x, int origin_y);
  * @param dest_x the X position you expect the mouse to move to
  * @param dest_y the Y position you expect the mouse to move to
  */
-int xdo_mouse_wait_for_move_to(const xdo_t *xdo, int dest_x, int dest_y);
+int xdo_wait_for_mouse_move_to(const xdo_t *xdo, int dest_x, int dest_y);
 
 /**
  * Send a click for a specific mouse button at the current mouse location.
@@ -331,7 +345,7 @@ int xdo_mouse_wait_for_move_to(const xdo_t *xdo, int dest_x, int dest_y);
  * @param button The mouse button. Generally, 1 is left, 2 is middle, 3 is
  *    right, 4 is wheel up, 5 is wheel down.
  */
-int xdo_click(const xdo_t *xdo, Window window, int button);
+int xdo_click_window(const xdo_t *xdo, Window window, int button);
 
 /**
  * Send a one or more clicks for a specific mouse button at the current mouse
@@ -341,21 +355,21 @@ int xdo_click(const xdo_t *xdo, Window window, int button);
  * @param button The mouse button. Generally, 1 is left, 2 is middle, 3 is
  *    right, 4 is wheel up, 5 is wheel down.
  */
-int xdo_click_multiple(const xdo_t *xdo, Window window, int button,
+int xdo_click_window_multiple(const xdo_t *xdo, Window window, int button,
                        int repeat, useconds_t delay);
 
 /**
  * Type a string to the specified window.
  *
  * If you want to send a specific key or key sequence, such as "alt+l", you
- * want instead xdo_keysequence(...).
+ * want instead xdo_send_keysequence_window(...).
  *
  * @param window The window you want to send keystrokes to or CURRENTWINDOW
  * @param string The string to type, like "Hello world!"
  * @param delay The delay between keystrokes in microseconds. 12000 is a decent
  *    choice if you don't have other plans.
  */
-int xdo_type(const xdo_t *xdo, Window window, char *string, useconds_t delay);
+int xdo_enter_text_window(const xdo_t *xdo, Window window, const char *string, useconds_t delay);
 
 /**
  * Send a keysequence to the specified window.
@@ -371,30 +385,30 @@ int xdo_type(const xdo_t *xdo, Window window, char *string, useconds_t delay);
  *   "Alt_L+Tab"
  *
  * If you want to type a string, such as "Hello world." you want to instead
- * use xdo_type.
+ * use xdo_enter_text_window.
  *
  * @param window The window you want to send the keysequence to or
  *   CURRENTWINDOW
  * @param keysequence The string keysequence to send.
  * @param delay The delay between keystrokes in microseconds.
  */
-int xdo_keysequence(const xdo_t *xdo, Window window,
+int xdo_send_keysequence_window(const xdo_t *xdo, Window window,
                     const char *keysequence, useconds_t delay);
 
 /**
  * Send key release (up) events for the given key sequence.
  *
- * @see xdo_keysequence
+ * @see xdo_send_keysequence_window
  */
-int xdo_keysequence_up(const xdo_t *xdo, Window window,
+int xdo_send_keysequence_window_up(const xdo_t *xdo, Window window,
                        const char *keysequence, useconds_t delay);
 
 /**
  * Send key press (down) events for the given key sequence.
  *
- * @see xdo_keysequence
+ * @see xdo_send_keysequence_window
  */
-int xdo_keysequence_down(const xdo_t *xdo, Window window,
+int xdo_send_keysequence_window_down(const xdo_t *xdo, Window window,
                          const char *keysequence, useconds_t delay);
                          
 /**
@@ -408,7 +422,7 @@ int xdo_keysequence_down(const xdo_t *xdo, Window window,
  *   the keys being pressed. If NULL, we don't save the modifiers.
  * @param delay The delay between keystrokes in microseconds.
  */
-int xdo_keysequence_list_do(const xdo_t *xdo, Window window,
+int xdo_send_keysequence_window_list_do(const xdo_t *xdo, Window window,
                             charcodemap_t *keys, int nkeys,
                             int pressed, int *modifier, useconds_t delay);
 
@@ -419,7 +433,7 @@ int xdo_keysequence_list_do(const xdo_t *xdo, Window window,
  *    by this function.
  * @param nkeys Pointer to integer where the number of keys will be stored.
  */
-int xdo_active_keys_to_keycode_list(const xdo_t *xdo, charcodemap_t **keys,
+int xdo_get_active_keys_to_keycode_list(const xdo_t *xdo, charcodemap_t **keys,
                                          int *nkeys);
 
 /**
@@ -434,11 +448,11 @@ int xdo_active_keys_to_keycode_list(const xdo_t *xdo, charcodemap_t **keys,
  * @param wid the window you want to wait for.
  * @param map_state the state to wait for.
  */
-int xdo_window_wait_for_map_state(const xdo_t *xdo, Window wid, int map_state);
+int xdo_wait_for_window_map_state(const xdo_t *xdo, Window wid, int map_state);
 
 #define SIZE_TO 0
 #define SIZE_FROM 1
-int xdo_window_wait_for_size(const xdo_t *xdo, Window window, unsigned int width,
+int xdo_wait_for_window_size(const xdo_t *xdo, Window window, unsigned int width,
                              unsigned int height, int flags, int to_or_from);
 
 
@@ -451,7 +465,7 @@ int xdo_window_wait_for_size(const xdo_t *xdo, Window window, unsigned int width
  * @param x the X coordinate to move to.
  * @param y the Y coordinate to move to.
  */
-int xdo_window_move(const xdo_t *xdo, Window wid, int x, int y);
+int xdo_move_window(const xdo_t *xdo, Window wid, int x, int y);
 
 /**
  * Apply a window's sizing hints (if any) to a given width and height.
@@ -465,9 +479,9 @@ int xdo_window_move(const xdo_t *xdo, Window wid, int x, int y);
  * @param width_ret the return location of the translated width
  * @param height_ret the return locatino of the translated height
  */
-int xdo_window_translate_with_sizehint(const xdo_t *xdo, Window window,
-                                       int width, int height, int *width_ret,
-                                       int *height_ret);
+int xdo_translate_window_with_sizehint(const xdo_t *xdo, Window window,
+                                       unsigned int width, unsigned int height,
+                                       unsigned int *width_ret, unsigned int *height_ret);
 
 /**
  * Change the window size.
@@ -478,7 +492,7 @@ int xdo_window_translate_with_sizehint(const xdo_t *xdo, Window window,
  * @param flags if 0, use pixels for units. If SIZE_USEHINTS, then
  *   the units will be relative to the window size hints.
  */
-int xdo_window_setsize(const xdo_t *xdo, Window wid, int w, int h, int flags);
+int xdo_set_window_size(const xdo_t *xdo, Window wid, int w, int h, int flags);
 
 /**
  * Change a window property.
@@ -489,17 +503,22 @@ int xdo_window_setsize(const xdo_t *xdo, Window wid, int w, int h, int flags);
  * @param property the string name of the property.
  * @param value the string value of the property.
  */
-int xdo_window_setprop (const xdo_t *xdo, Window wid, const char *property,
+int xdo_set_window_property(const xdo_t *xdo, Window wid, const char *property,
                         const char *value);
 
 /**
  * Change the window's classname and or class.
  *
  * @param name The new class name. If NULL, no change.
- * @param class The new class. If NULL, no change.
+ * @param _class The new class. If NULL, no change.
  */
-int xdo_window_setclass(const xdo_t *xdo, Window wid, const char *name,
-                        const char *class);
+int xdo_set_window_class(const xdo_t *xdo, Window wid, const char *name,
+                        const char *_class);
+
+/**
+ * Sets the urgency hint for a window.
+ */
+int xdo_set_window_urgency (const xdo_t *xdo, Window wid, int urgency);
 
 /**
  * Set the override_redirect value for a window. This generally means
@@ -510,16 +529,16 @@ int xdo_window_setclass(const xdo_t *xdo, Window wid, const char *name,
  * normal application window.
  *
  */
-int xdo_window_set_override_redirect(const xdo_t *xdo, Window wid,
+int xdo_set_window_override_redirect(const xdo_t *xdo, Window wid,
                                      int override_redirect);
 
 /**
  * Focus a window.
  *
- * @see xdo_window_activate
+ * @see xdo_activate_window
  * @param wid the window to focus.
  */
-int xdo_window_focus(const xdo_t *xdo, Window wid);
+int xdo_focus_window(const xdo_t *xdo, Window wid);
 
 /**
  * Raise a window to the top of the window stack. This is also sometimes
@@ -527,7 +546,7 @@ int xdo_window_focus(const xdo_t *xdo, Window wid);
  *
  * @param wid The window to raise.
  */
-int xdo_window_raise(const xdo_t *xdo, Window wid);
+int xdo_raise_window(const xdo_t *xdo, Window wid);
 
 /**
  * Get the window currently having focus.
@@ -535,7 +554,7 @@ int xdo_window_raise(const xdo_t *xdo, Window wid);
  * @param window_ret Pointer to a window where the currently-focused window
  *   will be stored.
  */
-int xdo_window_get_focus(const xdo_t *xdo, Window *window_ret);
+int xdo_get_focused_window(const xdo_t *xdo, Window *window_ret);
 
 /**
  * Wait for a window to have or lose focus.
@@ -543,7 +562,7 @@ int xdo_window_get_focus(const xdo_t *xdo, Window *window_ret);
  * @param window The window to wait on
  * @param want_focus If 1, wait for focus. If 0, wait for loss of focus.
  */
-int xdo_window_wait_for_focus(const xdo_t *xdo, Window window, int want_focus);
+int xdo_wait_for_window_focus(const xdo_t *xdo, Window window, int want_focus);
 
 /**
  * Get the PID owning a window. Not all applications support this.
@@ -552,10 +571,10 @@ int xdo_window_wait_for_focus(const xdo_t *xdo, Window window, int want_focus);
  * @param window the window to query.
  * @return the process id or 0 if no pid found.
  */
-int xdo_window_get_pid(const xdo_t *xdo, Window window);
+int xdo_get_pid_window(const xdo_t *xdo, Window window);
 
 /**
- * Like xdo_window_get_focus, but return the first ancestor-or-self window *
+ * Like xdo_get_focused_window, but return the first ancestor-or-self window *
  * having a property of WM_CLASS. This allows you to get the "real" or
  * top-level-ish window having focus rather than something you may not expect
  * to be the window having focused.
@@ -563,10 +582,10 @@ int xdo_window_get_pid(const xdo_t *xdo, Window window);
  * @param window_ret Pointer to a window where the currently-focused window
  *   will be stored.
  */
-int xdo_window_sane_get_focus(const xdo_t *xdo, Window *window_ret);
+int xdo_get_focused_window_sane(const xdo_t *xdo, Window *window_ret);
 
 /**
- * Activate a window. This is generally a better choice than xdo_window_focus
+ * Activate a window. This is generally a better choice than xdo_focus_window
  * for a variety of reasons, but it requires window manager support:
  *   - If the window is on another desktop, that desktop is switched to.
  *   - It moves the window forward rather than simply focusing it
@@ -576,7 +595,7 @@ int xdo_window_sane_get_focus(const xdo_t *xdo, Window *window_ret);
  *
  * @param wid the window to activate
  */
-int xdo_window_activate(const xdo_t *xdo, Window wid);
+int xdo_activate_window(const xdo_t *xdo, Window wid);
 
 /**
  * Wait for a window to be active or not active.
@@ -587,7 +606,7 @@ int xdo_window_activate(const xdo_t *xdo, Window wid);
  * @param window the window to wait on
  * @param active If 1, wait for active. If 0, wait for inactive.
  */
-int xdo_window_wait_for_active(const xdo_t *xdo, Window window, int active);
+int xdo_wait_for_window_active(const xdo_t *xdo, Window window, int active);
 
 /**
  * Map a window. This mostly means to make the window visible if it is
@@ -595,19 +614,19 @@ int xdo_window_wait_for_active(const xdo_t *xdo, Window window, int active);
  *
  * @param wid the window to map.
  */
-int xdo_window_map(const xdo_t *xdo, Window wid);
+int xdo_map_window(const xdo_t *xdo, Window wid);
 
 /**
  * Unmap a window
  *
  * @param wid the window to unmap
  */
-int xdo_window_unmap(const xdo_t *xdo, Window wid);
+int xdo_unmap_window(const xdo_t *xdo, Window wid);
 
 /**
  * Minimize a window.
  */
-int xdo_window_minimize(const xdo_t *xdo, Window wid);
+int xdo_minimize_window(const xdo_t *xdo, Window wid);
 
 /** 
  * Reparents a window
@@ -615,7 +634,7 @@ int xdo_window_minimize(const xdo_t *xdo, Window wid);
  * @param wid_source the window to reparent
  * @param wid_target the new parent window
  */
-int xdo_window_reparent(const xdo_t *xdo, Window wid_source, Window wid_target);
+int xdo_reparent_window(const xdo_t *xdo, Window wid_source, Window wid_target);
 
 /**
  * Get a window's location.
@@ -650,7 +669,7 @@ int xdo_get_window_size(const xdo_t *xdo, Window wid, unsigned int *width_ret,
  *
  * @param window_ret Pointer to Window where the active window is stored.
  */
-int xdo_window_get_active(const xdo_t *xdo, Window *window_ret);
+int xdo_get_active_window(const xdo_t *xdo, Window *window_ret);
 
 /**
  * Get a window ID by clicking on it. This function blocks until a selection
@@ -658,7 +677,7 @@ int xdo_window_get_active(const xdo_t *xdo, Window *window_ret);
  *
  * @param window_ret Pointer to Window where the selected window is stored.
  */
-int xdo_window_select_with_click(const xdo_t *xdo, Window *window_ret);
+int xdo_select_window_with_click(const xdo_t *xdo, Window *window_ret);
 
 /**
  * Set the number of desktops.
@@ -706,6 +725,9 @@ int xdo_set_desktop_for_window(const xdo_t *xdo, Window wid, long desktop);
  * Get the desktop a window is on.
  * Uses _NET_WM_DESKTOP of the EWMH spec.
  *
+ * If your desktop does not support _NET_WM_DESKTOP, then '*desktop' remains
+ * unmodified.
+ *
  * @param wid the window to query
  * @param deskto pointer to long where the desktop of the window is stored
  */
@@ -719,8 +741,8 @@ int xdo_get_desktop_for_window(const xdo_t *xdo, Window wid, long *desktop);
  * @param nwindows_ret the number of windows (length of windowlist_ret)
  * @see xdo_search_t
  */
-int xdo_window_search(const xdo_t *xdo, const xdo_search_t *search,
-                      Window **windowlist_ret, int *nwindows_ret);
+int xdo_search_windows(const xdo_t *xdo, const xdo_search_t *search,
+                      Window **windowlist_ret, unsigned int *nwindows_ret);
 
 /**
  * Generic property fetch.
@@ -733,9 +755,23 @@ int xdo_window_search(const xdo_t *xdo, const xdo_search_t *search,
  * @return data consisting of 'nitems' items of size 'size' and type 'type'
  *   will need to be cast to the type before using.
  */
-unsigned char *xdo_getwinprop(const xdo_t *xdo, Window window, Atom atom,
+unsigned char *xdo_get_window_property_by_atom(const xdo_t *xdo, Window window, Atom atom,
                               long *nitems, Atom *type, int *size);
 
+/**
+ * Get property of window by name of atom.
+ *
+ * @param window the window to query
+ * @param property the name of the atom
+ * @param nitems the number of items 
+ * @param type the type of the return
+ * @param size the size of the type
+ * @return data consisting of 'nitems' items of size 'size' and type 'type'
+ *   will need to be cast to the type before using.
+ */
+int xdo_get_window_property(const xdo_t *xdo, Window window, const char *property,
+                            unsigned char **value, long *nitems, Atom *type, int *size);
+
 /**
  * Get the current input state. This is a mask value containing any of the
  * following: ShiftMask, LockMask, ControlMask, Mod1Mask, Mod2Mask, Mod3Mask,
@@ -749,7 +785,7 @@ unsigned int xdo_get_input_state(const xdo_t *xdo);
  * If you need the keysym-to-character map, you can fetch it using this method.
  * @see keysym_charmap_t
  */
-const keysym_charmap_t *xdo_keysym_charmap(void);
+const keysym_charmap_t *xdo_get_keysym_charmap(void);
 
 /**
  * If you need the symbol map, use this method.
@@ -759,14 +795,19 @@ const keysym_charmap_t *xdo_keysym_charmap(void);
  *
  * @returns array of strings.
  */
-const char **xdo_symbol_map(void);
+const char **xdo_get_symbol_map(void);
 
 /* active modifiers stuff */
 
 /**
- * Get the currently-active modifiers
+ * Get a list of active keys. Uses XQueryKeymap.
+ *
+ * @param keys Pointer to the array of charcodemap_t that will be allocated
+ *    by this function.
+ * @param nkeys Pointer to integer where the number of keys will be stored.
  */
-xdo_active_mods_t *xdo_get_active_modifiers(const xdo_t *xdo);
+int xdo_get_active_modifiers(const xdo_t *xdo, charcodemap_t **keys,
+                             int *nkeys);
 
 /**
  * Send any events necesary to clear the the active modifiers.
@@ -774,7 +815,8 @@ xdo_active_mods_t *xdo_get_active_modifiers(const xdo_t *xdo);
  * called, then this method will send a key-up for 'alt'
  */
 int xdo_clear_active_modifiers(const xdo_t *xdo, Window window,
-                               xdo_active_mods_t *active_mods);
+                               charcodemap_t *active_mods,
+                               int active_mods_n);
 
 /**
  * Send any events necessary to make these modifiers active.
@@ -782,12 +824,8 @@ int xdo_clear_active_modifiers(const xdo_t *xdo, Window window,
  * to restore them after.
  */
 int xdo_set_active_modifiers(const xdo_t *xdo, Window window,
-                             const xdo_active_mods_t *active_mods);
-
-/**
- * Free the data allocated by xdo_get_active_modifiers.
- */
-void xdo_free_active_modifiers(xdo_active_mods_t *active_mods);
+                             charcodemap_t *active_mods,
+                             int active_mods_n);
 
 /**
  * Get the position of the current viewport.
@@ -809,7 +847,7 @@ int xdo_set_desktop_viewport(const xdo_t *xdo, int x, int y);
  * Kill a window and the client owning it.
  *
  */
-int xdo_window_kill(const xdo_t *xdo, Window window);
+int xdo_kill_window(const xdo_t *xdo, Window window);
 
 /**
  * Find a client window that is a parent of the window given
@@ -825,7 +863,7 @@ int xdo_window_kill(const xdo_t *xdo, Window window);
  * Find a client window (child) in a given window. Useful if you get the
  * window manager's decorator window rather than the client window.
  */
-int xdo_window_find_client(const xdo_t *xdo, Window window, Window *window_ret,
+int xdo_find_window_client(const xdo_t *xdo, Window window, Window *window_ret,
                            int direction);
 
 /**
@@ -837,4 +875,43 @@ int xdo_get_window_name(const xdo_t *xdo, Window window,
                         unsigned char **name_ret, int *name_len_ret,
                         int *name_type);
 
+/**
+ * Disable an xdo feature.
+ *
+ * This function is mainly used by libxdo itself, however, you may find it useful
+ * in your own applications.
+ * 
+ * @see XDO_FEATURES
+ */
+void xdo_disable_feature(xdo_t *xdo, int feature);
+
+/**
+ * Enable an xdo feature.
+ *
+ * This function is mainly used by libxdo itself, however, you may find it useful
+ * in your own applications.
+ * 
+ * @see XDO_FEATURES
+ */
+void xdo_enable_feature(xdo_t *xdo, int feature);
+
+/**
+ * Check if a feature is enabled.
+ *
+ * This function is mainly used by libxdo itself, however, you may find it useful
+ * in your own applications.
+ * 
+ * @see XDO_FEATURES
+ */
+int xdo_has_feature(xdo_t *xdo, int feature);
+
+/**
+ * Query the viewport (your display) dimensions
+ *
+ * If Xinerama is active and supported, that api internally is used.
+ * If Xineram is disabled, we will report the root window's dimensions
+ * for the given screen.
+ */
+int xdo_get_viewport_dimensions(xdo_t *xdo, unsigned int *width,
+                                unsigned int *height, int screen);
 #endif /* ifndef _XDO_H_ */
