@@ -334,7 +334,7 @@ int script_main(int argc, char **argv) {
   strcpy(script_argv[0], argv[0]);
 
   /* determine whether reading from a file or from stdin */
-  if (!strcmp(path, "-") || !isatty(0)) {
+  if (!strcmp(path, "-")) {
     input = fdopen(0, "r");
   } else {
     input = fopen(path, "r");
@@ -581,6 +581,7 @@ void xdotool_debug(context_t *context, const char *format, ...) {
 } /* xdotool_debug */
 
 void xdotool_output(context_t *context, const char *format, ...) {
+  context = context; /* Do something with context to avoid warnings */
   va_list args;
 
   va_start(args, format);
